Coverex.Task

Summary

cover_class(arg1)
coverage_data()

Returns detailed coverage data {mod, mf} for all modules from the :cover application

encode_html(s, acc \\ "")
module_anchor(m)
overview_entry_template(entry, cov, uncov, ratio)
overview_template(title, entries)
post_coveralls(mods, output, job_id, url \\ "https://coveralls.io/api/v1/jobs")
post_to_coveralls?(opts)

is post to coveralls requested?

running_travis?(env \\ System.get_env())
send_http(url, filename, body)
source_line_template(number, count, source, anchor)
source_template(title, lines)
start(compile_path, opts)

Starts the Coverex coverage data generation. An additional option is

travis_job_id(env \\ System.get_env())

gets the travis job id out of the environment

write_function_overview(functions, output)
write_html_file(mod, output)
write_module_overview(modules, output)

Functions

cover_class(arg1)
coverage_data()

Returns detailed coverage data {mod, mf} for all modules from the :cover application.

The `mod` data

The mod data is a list of pairs: {modulename, {no of covered lines, no of uncovered lines}}

The `mf` data

The mf data is list of pairs: {{m, f, a}, {no of covered lines, no of uncovered lines}}

encode_html(s, acc \\ "")
module_anchor(m)
overview_entry_template(entry, cov, uncov, ratio)
overview_template(title, entries)
post_coveralls(mods, output, job_id, url \\ "https://coveralls.io/api/v1/jobs")

Specs:

post_to_coveralls?(opts)

is post to coveralls requested?

running_travis?(env \\ System.get_env())

Specs:

send_http(url, filename, body)
source_line_template(number, count, source, anchor)
source_template(title, lines)
start(compile_path, opts)

Starts the Coverex coverage data generation. An additional option is

log: :error

which sets the log-level of the Elixir Logger application. Default value is :error. For debugging purposes, it can be set to :debug. In this case, the output is quite noisy…

travis_job_id(env \\ System.get_env())

Specs:

gets the travis job id out of the environment

write_function_overview(functions, output)
write_html_file(mod, output)
write_module_overview(modules, output)
Source